@@ -555,11 +555,19 @@ class BaseListView(ListModelMixin, RetrieveModelMixin, GenericAPIView):
         return ret
 
     def _get_key_from_query_dc_or_self(self, key):
+        """
+        优先检索query_dc是否有key, 其次检索self是否有key这个属性
+        :param key: 变量名
+        :return:
+        """
+
         query_dc = self.get_request_data()
         data = query_dc.get(key)
 
-        ret = data if data else None
-        ret = getattr(self, key) if hasattr(self, key) else None
+        ret_0 = getattr(self, key) if hasattr(self, key) else None
+        ret_1 = data if data else None
+
+        ret = ret_1 or ret_0
         return ret
 
 
